@@ -60,16 +60,26 @@ cli_opts = [
                      'Can be supplied as "ipa-listen-port" kernel parameter.'),
 
     # This is intentionally not settable via kernel command line, as it
-    # requires configuration parameters from oslo_service which are not
-    # configurable over the command line and require files-on-disk.
+    # requires configuration parameters which are not configurable over
+    # the command line and require files-on-disk.
     # Operators who want to use this support should configure it statically
     # as part of a ramdisk build.
     cfg.BoolOpt('listen_tls',
                 default=False,
                 help='When true, IPA will host API behind TLS. You will also '
-                     'need to configure [ssl] group options for cert_file, '
-                     'key_file, and, if desired, ca_file to validate client '
-                     'certificates.'),
+                     'need to configure tls_cert_file option and tls_key_file '
+                     'option.'),
+
+    cfg.StrOpt('tls_cert_file',
+               help="Certificate file to use when starting "
+                    "the server securely.",
+               deprecated_group='ssl',
+               deprecated_name='cert_file'),
+    cfg.StrOpt('tls_key_file',
+               help="Private key file to use when starting "
+                    "the server securely.",
+               deprecated_group='ssl',
+               deprecated_name='key_file'),
 
     cfg.BoolOpt('enable_auto_tls',
                 default=True,
@@ -292,12 +302,6 @@ cli_opts = [
                     'This variable can be also configured via image_info.'
                     'Value coming from image_info takes precedence over'
                     'value coming from command line or configuration file.'),
-    cfg.BoolOpt('agent_token_required',
-                default=APARAMS.get('ipa-agent-token-required', False),
-                help='Control to enforce if API command requests should '
-                     'enforce token validation. The configuration provided '
-                     'by the conductor MAY override this and force this '
-                     'setting to be changed to True in memory.'),
     cfg.IntOpt('image_download_connection_timeout', min=1,
                default=APARAMS.get(
                    'ipa-image-download-connection-timeout', 60),
@@ -442,13 +446,42 @@ disk_part_opts = [
                     ' having failed.')
 ]
 
+container_opts = [
+    cfg.BoolOpt('allow_arbitrary_containers',
+                default=False,
+                help='Allow arbitrary containers to be run'
+                     'without restriction.'),
+    cfg.ListOpt('allowed_containers',
+                default=[],
+                help='List of allowed containers that can be run.'),
+    cfg.StrOpt('container_steps_file',
+               default='/etc/ironic-python-agent.d/mysteps.yaml',
+               help='Path to the YAML file containing container-based'
+                    'cleaning steps.'),
+    cfg.StrOpt('runner',
+               default='podman',
+               choices=['podman', 'docker'],
+               help='Container runtime to use for cleaning steps.'),
+    cfg.ListOpt('pull_options',
+                default=['--tls-verify=false'],
+                help='Options to use when pulling container images.'),
+    cfg.ListOpt('run_options',
+                default=['--rm', '--network=host', '--tls-verify=false'],
+                help='Options to use when running containers.'),
+    cfg.StrOpt('container_conf_file',
+               default='/etc/containers/containers.conf',
+               help='Path to the container configuration file in the IPA RAM')
+]
+
 
 def list_opts():
     return [('DEFAULT', cli_opts),
             ('disk_utils', disk_utils_opts),
             ('disk_partitioner', disk_part_opts),
             ('metrics', metrics_opts),
-            ('metrics_statsd', statsd_opts)]
+            ('metrics_statsd', statsd_opts),
+            ('container', container_opts)
+            ]
 
 
 def populate_config():
@@ -458,6 +491,7 @@ def populate_config():
     CONF.register_opts(disk_part_opts, group='disk_partitioner')
     CONF.register_opts(metrics_opts, group='metrics')
     CONF.register_opts(statsd_opts, group='metrics_statsd')
+    CONF.register_opts(container_opts, group='container')
 
 
 def override(params):
